#========================================================================================
# package      Training::MyStaticStyle::API::Cartridge
# state        public
#----------------------------------------------------------------------------------------
# description  main cartridge class for install/patch/uninstall
#========================================================================================
package Training::MyStaticStyle::API::Cartridge;
use base qw (DE_EPAGES::Design::API::DesignInstaller);

use strict;

#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       Training::MyStaticStyle::API::Cartridge->new(%options);
#----------------------------------------------------------------------------------------
# description  Creates a new installer object of Training::MyStaticStyle
#----------------------------------------------------------------------------------------
# input        %options | options for un/install keys
#               <ul>
#                 <li>IsRecursive - recursive un/installation of required or dependent cartridges
#               </ul>
#               | hash
#========================================================================================
sub new {
    my ($class, %options) = @_;

    my $self = __PACKAGE__->SUPER::new(
        %options,
        CartridgeDirectory => 'Training/MyStaticStyle',
        Version            => '1.0',
    );
    return bless $self, $class;
}

#========================================================================================
# function     install
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Installer->install;
#----------------------------------------------------------------------------------------
# description  Installs the cartridge
#========================================================================================
sub install {
    my $self = shift;

    $self->startInstall;
    $self->SUPER::install;
    $self->finishInstall;
}

#========================================================================================
# function     uninstall
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Installer->uninstall;
#----------------------------------------------------------------------------------------
# description  Uninstalls the cartridge
#========================================================================================
sub uninstall {
    my $self = shift;

    $self->startUninstall;
    $self->SUPER::uninstall;
    $self->finishUninstall;
}

1;
