#==============================================================================
# package      DE_EPAGES::WorldPay::UI::Basket
# base         DE_EPAGES::Presentation::UI::Object
# state        private
#==============================================================================
package DE_EPAGES::WorldPay::UI::Basket;
use base DE_EPAGES::Presentation::UI::Object;

use strict;

use Digest::MD5 qw (md5_hex);
use DE_EPAGES::Core::API::PerlTools qw (isValid);
use DE_EPAGES::Core::API::CSV qw (CombineCSV);

#========================================================================================
# function     ViewPaymentWorldPay
# state        private
#----------------------------------------------------------------------------------------
# syntax       $Handler->ViewPaymentWorldPay( $Servlet );
#----------------------------------------------------------------------------------------
# description  Joins current cookies to parameter 'CustSettings'.
#----------------------------------------------------------------------------------------
# input        $Servlet | servlet | object
#========================================================================================
sub ViewPaymentWorldPay {
    my $self = shift;
    my ($Servlet) = @_;

    $self->SUPER::View($Servlet);
    my $Cookies = $Servlet->cookies();
    my @Values;
    foreach my $key (keys %$Cookies) {
        next if $key eq 'SessionID';
        push (@Values, CombineCSV([$key,$Cookies->{$key}], { 'sep_char' => ':' }));
    }
    my $ret = CombineCSV([sort @Values], { 'sep_char' => ',' });
    $Servlet->params('CustSettings',$ret);

    my $LineItemPayment = $Servlet->object()->get('LineItemContainer')->get('Payment');
    my $PaymentMethod   = $LineItemPayment->get('PaymentMethod');
    $LineItemPayment->set({'IsTestTransaction' => $PaymentMethod->get('IsInTestMode')});

    if ( isValid($PaymentMethod->get('TransactionSecret'))){
        my $SignatureFields = join(':','instId','cartId','currency');
        my $Secret = join(';',  $PaymentMethod->get('TransactionSecret'),
                                $SignatureFields,
                                $PaymentMethod->get('InstallationID'),  #instId
                                $LineItemPayment->get('GUID'),          #cartId
                                $LineItemPayment->get('CurrencyID')     #currency
                         );
        $Servlet->params('TransactionSecretCrypted', md5_hex($Secret));
    }
    return;
}

1;

